==> moodle_1.3.1.orig.tar.gz: moodle/lang/fi/editor.php <==
<?PHP // $Id: editor.php,v 1.8 2004/05/25 16:39:31 paca70 Exp $ 
      // editor.php - created with Moodle 1.3 Nearly Ready (2004052000)


$string['about'] = 'Tietoja editorista';
$string['absbottom'] = 'Absbottom';
$string['absmiddle'] = 'Absmiddle';
$string['address'] = 'Osoite';
$string['alignment'] = 'Tasaus';
$string['alternatetext'] = 'Oletusteksti';
$string['baseline'] = 'Baseline';
$string['bold'] = 'Lihavoitu';
$string['borderthickness'] = 'Reunan paksuus';
$string['bottom'] = 'Alas';
$string['browse'] = 'Selaa';
$string['cancel'] = 'Peruuta';
$string['cellpadding'] = 'Solun tytt';
$string['cellspacing'] = 'Solujen vli';
$string['choosechar'] = 'Valitse merkki';
$string['chooseicon'] = 'Valitse liitettv hymi';
$string['close'] = 'Sulje';
$string['cols'] = 'Solut';
$string['copy'] = 'Kopioi';
$string['createfolder'] = 'Luo kansio';
$string['createlink'] = 'Lis linkki';
$string['cut'] = 'Leikkaa';
$string['delete'] = 'Poista';
$string['filebrowser'] = 'Tiedostoselain';
$string['forecolor'] = 'Tekstin vri';
$string['fullscreen'] = 'Tysdenruudun editori';
$string['heading'] = 'Otsikko';
$string['height'] = 'Korkeus';
$string['hilitecolor'] = 'Taustan vri';
$string['horizontal'] = 'Vaaka';
$string['horizontalrule'] = 'Vaakaviiva';
$string['htmlmode'] = 'Nyt HTML-koodi';
$string['imageurl'] = 'Kuvan URL';
$string['indent'] = 'Lis sisennyst';
$string['insertchar'] = 'Lis merkki';
$string['insertimage'] = 'Lis kuva';
$string['insertlink'] = 'Lis linkki';
$string['insertsmile'] = 'Lis hymi';
$string['inserttable'] = 'Lis taulukko';
$string['italic'] = 'Kursivoitu';
$string['justifycenter'] = 'Keskit';
$string['justifyfull'] = 'Tasaa molemmat reunat';
$string['justifyleft'] = 'Tasaa vasemmat reunat';
$string['justifyright'] = 'Tasaa oikeat reunat';
$string['layout'] = 'Ulkoasu';
$string['left'] = 'Vasen';
$string['lefttoright'] = 'Suunta vesemmalta oikealle';
$string['linkproperties'] = 'Linkin ominaisuudet';
$string['linktarget'] = 'Linkin kohde';
$string['linktargetblank'] = 'Uuteen ikkunaan';
$string['linktargetnone'] = 'Ei kohdetta';
$string['linktargetother'] = 'Muuhun kehykseen (ei toiminnassa)';
$string['linktargetself'] = 'Samaan kehykseen';
$string['linktargettop'] = 'Samaan ikkunaan';
$string['linktitle'] = 'Otsikko';
$string['linkurl'] = 'URL';
$string['middle'] = 'Keskit';
$string['minimize'] = 'Pienenn editori';
$string['move'] = 'Siirr';
$string['normal'] = 'Normaali';
$string['notimage'] = 'Valittu tiedosto ei ollut kuva. Valitse kuvatiedosto!';
$string['notset'] = 'Ei valittua';
$string['ok'] = 'OK';
$string['orderedlist'] = 'Numerointi';
$string['outdent'] = 'Vhenn sisennyst';
$string['paste'] = 'Liit';
$string['path'] = 'Polku';
$string['percent'] = 'Prosenttia';
$string['pixels'] = 'Pikseli';
$string['popupeditor'] = 'Suurenna editori';
$string['preformatted'] = 'Muotoiltu (pre)';
$string['preview'] = 'Esikatsele';
$string['properties'] = 'Ominaisuudet';
$string['redo'] = 'Palauta viimeinen toiminto';
$string['removelink'] = 'Poista linkki';
$string['rename'] = 'Nime uudelleen';
$string['right'] = 'Oikea';
$string['righttoleft'] = 'Suunta oikealta vesemmalle';
$string['rows'] = 'Rivit';
$string['selectcolor'] = 'Valitse vri';
$string['selection'] = 'Valinta';
$string['showhelp'] = 'Ohje';
$string['size'] = 'Koko';
$string['spacing'] = 'Vlys';
$string['strikethrough'] = 'Yliviivattu';
$string['subscript'] = 'Alaindeksi';
$string['superscript'] = 'Yldeksi';
$string['textindicator'] = 'Nykyinen tyyli';
$string['textmode'] = 'Olet tekstitilassa.  Kyt [<>] painiketta palataksesi takaisin WYSIWIG -tilaan.';
$string['texttop'] = 'Texttop';
$string['top'] = 'Yls';
$string['type'] = 'Tyyppi';
$string['underline'] = 'Alleviivattu';
$string['undo'] = 'Peruuta viimeinen toiminto';
$string['unorderedlist'] = 'Luettelomerkit';
$string['upload'] = 'Lataa';
$string['vertical'] = 'Pysty';
$string['width'] = 'Leveys';
$string['wordclean'] = 'Puhdista Word HTML';
$string['zip'] = 'Zip';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/fi/editor.php <==
<?PHP // $Id$ 
      // editor.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004110200)


$string['about'] = 'Tietoja editorista';
$string['absbottom'] = 'Absbottom';
$string['address'] = 'Osoite';
$string['alignment'] = 'Tasaus';
$string['alternatetext'] = 'Oletusteksti';
$string['anchorhelp'] = 'Tm luo vain ankkurin. Sinun pit luoda akkuriin viittaava linkki itse.';
$string['anchorname'] = 'Ankkurin nimi';
$string['anchors'] = 'Ankkurit';
$string['baseline'] = 'Baseline';
$string['bold'] = 'Lihavoitu';
$string['borderthickness'] = 'Reunan paksuus';
$string['bottom'] = 'Alas';
$string['browse'] = 'Selaa';
$string['cancel'] = 'Peruuta';
$string['cellpadding'] = 'Solun tytt';
$string['cellspacing'] = 'Solujen vli';
$string['choosechar'] = 'Valitse merkki';
$string['chooseicon'] = 'Valitse liitettv hymi';
$string['close'] = 'Sulje';
$string['cols'] = 'Solut';
$string['copy'] = 'Kopioi';
$string['createanchor'] = 'Luo ankkuri';
$string['createfolder'] = 'Luo kansio';
$string['createlink'] = 'Lis linkki';
$string['cut'] = 'Leikkaa';
$string['delete'] = 'Poista';
$string['filebrowser'] = 'Tiedostoselain';
$string['forecolor'] = 'Tekstin vri';
$string['fullscreen'] = 'Tydenruudun editori';
$string['heading'] = 'Otsikko';
$string['height'] = 'Korkeus';
$string['hilitecolor'] = 'Taustan vri';
$string['horizontal'] = 'Vaaka';
$string['horizontalrule'] = 'Vaakaviiva';
$string['htmlmode'] = 'Nyt HTML-koodi';
$string['imageurl'] = 'Kuvan URL';
$string['indent'] = 'Lis sisennyst';
$string['insertchar'] = 'Lis merkki';
$string['insertimage'] = 'Lis kuva';
$string['insertlink'] = 'Lis linkki';
$string['insertsmile'] = 'Lis hymi';
$string['inserttable'] = 'Lis taulukko';
$string['italic'] = 'Kursivoitu';
$string['justifycenter'] = 'Keskit';
$string['justifyfull'] = 'Tasaa molemmat reunat';
$string['justifyleft'] = 'Tasaa vasen reuna';
$string['justifyright'] = 'Tasaa oikea reuna';
$string['layout'] = 'Ulkoasu';
$string['left'] = 'Vasen';
$string['lefttoright'] = 'Suunta vesemmalta oikealle';
$string['linkproperties'] = 'Linkin ominaisuudet';
$string['linktarget'] = 'Linkin kohde';
$string['linktargetblank'] = 'Uuteen ikkunaan';
$string['linktargetnone'] = 'Ei kohdetta';
$string['linktargetother'] = 'Muuhun kehykseen (ei toiminnassa)';
$string['linktargetself'] = 'Samaan kehykseen';
$string['linktargettop'] = 'Samaan ikkunaan';
$string['linktitle'] = 'Otsikko';
$string['linkurl'] = 'URL';
$string['middle'] = 'Keskit';
$string['minimize'] = 'Pienenn editori';
$string['move'] = 'Siirr';
$string['normal'] = 'Normaali';
$string['notimage'] = 'Valittu tiedosto ei ollut kuva. Valitse kuvatiedosto!';
$string['notset'] = 'Ei valittua';
$string['ok'] = 'OK';
$string['orderedlist'] = 'Numerointi';
$string['outdent'] = 'Vhenn sisennyst';
$string['paste'] = 'Liit';
$string['path'] = 'Polku';
$string['percent'] = 'Prosenttia';
$string['pixels'] = 'Pikseli';
$string['popupeditor'] = 'Suurenna editori';
$string['preformatted'] = 'Muotoiltu (pre)';
$string['preview'] = 'Esikatsele';
$string['properties'] = 'Ominaisuudet';
$string['redo'] = 'Palauta viimeinen toiminto';
$string['removelink'] = 'Poista linkki';
$string['rename'] = 'Nime uudelleen';
$string['right'] = 'Oikea';
$string['righttoleft'] = 'Suunta oikealta vasemmalle';
$string['rows'] = 'Rivit';
$string['selectcolor'] = 'Valitse vri';
$string['selection'] = 'Valinta';
$string['showhelp'] = 'Ohje';
$string['size'] = 'Koko';
$string['spacing'] = 'Vlistys';
$string['strikethrough'] = 'Yliviivattu';
$string['subscript'] = 'Alaindeksi';
$string['superscript'] = 'Yldeksi';
$string['textindicator'] = 'Nykyinen tyyli';
$string['textmode'] = 'Olet tekstitilassa.  Kyt [<>] painiketta palataksesi takaisin WYSIWYG -tilaan.';
$string['texttop'] = 'Texttop';
$string['thischarset'] = 'iso-8859-1';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = 'Suomi';
$string['top'] = 'Yls';
$string['type'] = 'Tyyppi';
$string['underline'] = 'Alleviivattu';
$string['undo'] = 'Peruuta viimeinen toiminto';
$string['unorderedlist'] = 'Luettelomerkit';
$string['upload'] = 'Lataa';
$string['vertical'] = 'Pysty';
$string['width'] = 'Leveys';
$string['wordclean'] = 'Puhdista Word HTML';
$string['zip'] = 'Zip';

?>
